# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/service_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import service_account_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_service__account__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/service_account_service.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/iam/v1/service_account_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a)yandex/cloud/iam/v1/service_account.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"D\n\x18GetServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x97\x01\n\x1aListServiceAccountsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n\x1bListServiceAccountsResponse\x12=\n\x10service_accounts\x18\x01 \x03(\x0b\x32#.yandex.cloud.iam.v1.ServiceAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x93\x01\n\x1b\x43reateServiceAccountRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\":\n\x1c\x43reateServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"\xcd\x01\n\x1bUpdateServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\":\n\x1cUpdateServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"G\n\x1b\x44\x65leteServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x1c\x44\x65leteServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"\x8d\x01\n#ListServiceAccountOperationsRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"v\n$ListServiceAccountOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe8\r\n\x15ServiceAccountService\x12\x8f\x01\n\x03Get\x12-.yandex.cloud.iam.v1.GetServiceAccountRequest\x1a#.yandex.cloud.iam.v1.ServiceAccount\"4\x82\xd3\xe4\x93\x02.\x12,/iam/v1/serviceAccounts/{service_account_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.iam.v1.ListServiceAccountsRequest\x1a\x30.yandex.cloud.iam.v1.ListServiceAccountsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/iam/v1/serviceAccounts\x12\xb3\x01\n\x06\x43reate\x12\x30.yandex.cloud.iam.v1.CreateServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02\x1c\"\x17/iam/v1/serviceAccounts:\x01*\xb2\xd2*.\n\x1c\x43reateServiceAccountMetadata\x12\x0eServiceAccount\x12\xc8\x01\n\x06Update\x12\x30.yandex.cloud.iam.v1.UpdateServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x31\x32,/iam/v1/serviceAccounts/{service_account_id}:\x01*\xb2\xd2*.\n\x1cUpdateServiceAccountMetadata\x12\x0eServiceAccount\x12\xcc\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.iam.v1.DeleteServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02.*,/iam/v1/serviceAccounts/{service_account_id}\xb2\xd2*5\n\x1c\x44\x65leteServiceAccountMetadata\x12\x15google.protobuf.Empty\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/iam/v1/serviceAccounts/{resource_id}:listAccessBindings\x12\xe6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02<\"7/iam/v1/serviceAccounts/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf3\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\x82\xd3\xe4\x93\x02?\":/iam/v1/serviceAccounts/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x0eListOperations\x12\x38.yandex.cloud.iam.v1.ListServiceAccountOperationsRequest\x1a\x39.yandex.cloud.iam.v1.ListServiceAccountOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/iam/v1/serviceAccounts/{service_account_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_iam_dot_v1_dot_service__account__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSERVICEACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetServiceAccountRequest',
  full_name='yandex.cloud.iam.v1.GetServiceAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.GetServiceAccountRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=388,
)


_LISTSERVICEACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListServiceAccountsRequest',
  full_name='yandex.cloud.iam.v1.ListServiceAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iam.v1.ListServiceAccountsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListServiceAccountsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListServiceAccountsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.iam.v1.ListServiceAccountsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=542,
)


_LISTSERVICEACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListServiceAccountsResponse',
  full_name='yandex.cloud.iam.v1.ListServiceAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_accounts', full_name='yandex.cloud.iam.v1.ListServiceAccountsResponse.service_accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListServiceAccountsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=661,
)


_CREATESERVICEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateServiceAccountRequest',
  full_name='yandex.cloud.iam.v1.CreateServiceAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iam.v1.CreateServiceAccountRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iam.v1.CreateServiceAccountRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.CreateServiceAccountRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=811,
)


_CREATESERVICEACCOUNTMETADATA = _descriptor.Descriptor(
  name='CreateServiceAccountMetadata',
  full_name='yandex.cloud.iam.v1.CreateServiceAccountMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.CreateServiceAccountMetadata.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=871,
)


_UPDATESERVICEACCOUNTREQUEST = _descriptor.Descriptor(
  name='UpdateServiceAccountRequest',
  full_name='yandex.cloud.iam.v1.UpdateServiceAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.UpdateServiceAccountRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.iam.v1.UpdateServiceAccountRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iam.v1.UpdateServiceAccountRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.UpdateServiceAccountRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=1079,
)


_UPDATESERVICEACCOUNTMETADATA = _descriptor.Descriptor(
  name='UpdateServiceAccountMetadata',
  full_name='yandex.cloud.iam.v1.UpdateServiceAccountMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.UpdateServiceAccountMetadata.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1139,
)


_DELETESERVICEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeleteServiceAccountRequest',
  full_name='yandex.cloud.iam.v1.DeleteServiceAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.DeleteServiceAccountRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1212,
)


_DELETESERVICEACCOUNTMETADATA = _descriptor.Descriptor(
  name='DeleteServiceAccountMetadata',
  full_name='yandex.cloud.iam.v1.DeleteServiceAccountMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.DeleteServiceAccountMetadata.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1272,
)


_LISTSERVICEACCOUNTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListServiceAccountOperationsRequest',
  full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1416,
)


_LISTSERVICEACCOUNTOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListServiceAccountOperationsResponse',
  full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListServiceAccountOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1418,
  serialized_end=1536,
)

_LISTSERVICEACCOUNTSRESPONSE.fields_by_name['service_accounts'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_service__account__pb2._SERVICEACCOUNT
_UPDATESERVICEACCOUNTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTSERVICEACCOUNTOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetServiceAccountRequest'] = _GETSERVICEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ListServiceAccountsRequest'] = _LISTSERVICEACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListServiceAccountsResponse'] = _LISTSERVICEACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateServiceAccountRequest'] = _CREATESERVICEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CreateServiceAccountMetadata'] = _CREATESERVICEACCOUNTMETADATA
DESCRIPTOR.message_types_by_name['UpdateServiceAccountRequest'] = _UPDATESERVICEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['UpdateServiceAccountMetadata'] = _UPDATESERVICEACCOUNTMETADATA
DESCRIPTOR.message_types_by_name['DeleteServiceAccountRequest'] = _DELETESERVICEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeleteServiceAccountMetadata'] = _DELETESERVICEACCOUNTMETADATA
DESCRIPTOR.message_types_by_name['ListServiceAccountOperationsRequest'] = _LISTSERVICEACCOUNTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListServiceAccountOperationsResponse'] = _LISTSERVICEACCOUNTOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetServiceAccountRequest = _reflection.GeneratedProtocolMessageType('GetServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.GetServiceAccountRequest)
  })
_sym_db.RegisterMessage(GetServiceAccountRequest)

ListServiceAccountsRequest = _reflection.GeneratedProtocolMessageType('ListServiceAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEACCOUNTSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListServiceAccountsRequest)
  })
_sym_db.RegisterMessage(ListServiceAccountsRequest)

ListServiceAccountsResponse = _reflection.GeneratedProtocolMessageType('ListServiceAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEACCOUNTSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListServiceAccountsResponse)
  })
_sym_db.RegisterMessage(ListServiceAccountsResponse)

CreateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('CreateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateServiceAccountRequest)
  })
_sym_db.RegisterMessage(CreateServiceAccountRequest)

CreateServiceAccountMetadata = _reflection.GeneratedProtocolMessageType('CreateServiceAccountMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEACCOUNTMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateServiceAccountMetadata)
  })
_sym_db.RegisterMessage(CreateServiceAccountMetadata)

UpdateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVICEACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateServiceAccountRequest)
  })
_sym_db.RegisterMessage(UpdateServiceAccountRequest)

UpdateServiceAccountMetadata = _reflection.GeneratedProtocolMessageType('UpdateServiceAccountMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVICEACCOUNTMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateServiceAccountMetadata)
  })
_sym_db.RegisterMessage(UpdateServiceAccountMetadata)

DeleteServiceAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICEACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteServiceAccountRequest)
  })
_sym_db.RegisterMessage(DeleteServiceAccountRequest)

DeleteServiceAccountMetadata = _reflection.GeneratedProtocolMessageType('DeleteServiceAccountMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICEACCOUNTMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteServiceAccountMetadata)
  })
_sym_db.RegisterMessage(DeleteServiceAccountMetadata)

ListServiceAccountOperationsRequest = _reflection.GeneratedProtocolMessageType('ListServiceAccountOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEACCOUNTOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListServiceAccountOperationsRequest)
  })
_sym_db.RegisterMessage(ListServiceAccountOperationsRequest)

ListServiceAccountOperationsResponse = _reflection.GeneratedProtocolMessageType('ListServiceAccountOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEACCOUNTOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.service_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListServiceAccountOperationsResponse)
  })
_sym_db.RegisterMessage(ListServiceAccountOperationsResponse)


DESCRIPTOR._options = None
_GETSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
_LISTSERVICEACCOUNTSREQUEST.fields_by_name['folder_id']._options = None
_LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_size']._options = None
_LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_token']._options = None
_LISTSERVICEACCOUNTSREQUEST.fields_by_name['filter']._options = None
_CREATESERVICEACCOUNTREQUEST.fields_by_name['folder_id']._options = None
_CREATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
_CREATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
_UPDATESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
_UPDATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
_UPDATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
_DELETESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
_LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['service_account_id']._options = None
_LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_SERVICEACCOUNTSERVICE = _descriptor.ServiceDescriptor(
  name='ServiceAccountService',
  full_name='yandex.cloud.iam.v1.ServiceAccountService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1539,
  serialized_end=3307,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSERVICEACCOUNTREQUEST,
    output_type=yandex_dot_cloud_dot_iam_dot_v1_dot_service__account__pb2._SERVICEACCOUNT,
    serialized_options=b'\202\323\344\223\002.\022,/iam/v1/serviceAccounts/{service_account_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSERVICEACCOUNTSREQUEST,
    output_type=_LISTSERVICEACCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/iam/v1/serviceAccounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESERVICEACCOUNTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034\"\027/iam/v1/serviceAccounts:\001*\262\322*.\n\034CreateServiceAccountMetadata\022\016ServiceAccount',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESERVICEACCOUNTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\00212,/iam/v1/serviceAccounts/{service_account_id}:\001*\262\322*.\n\034UpdateServiceAccountMetadata\022\016ServiceAccount',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESERVICEACCOUNTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.*,/iam/v1/serviceAccounts/{service_account_id}\262\322*5\n\034DeleteServiceAccountMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.ListAccessBindings',
    index=5,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002:\0228/iam/v1/serviceAccounts/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.SetAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002<\"7/iam/v1/serviceAccounts/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.UpdateAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/iam/v1/serviceAccounts/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.iam.v1.ServiceAccountService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTSERVICEACCOUNTOPERATIONSREQUEST,
    output_type=_LISTSERVICEACCOUNTOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/iam/v1/serviceAccounts/{service_account_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICEACCOUNTSERVICE)

DESCRIPTOR.services_by_name['ServiceAccountService'] = _SERVICEACCOUNTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/ip_permission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/ip_permission.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/containerregistry/v1/ip_permission.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x0cIpPermission\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.containerregistry.v1.IpPermission.Action\x12\n\n\x02ip\x18\x02 \x01(\t\"4\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04PULL\x10\x01\x12\x08\n\x04PUSH\x10\x02\"\xae\x01\n\x11IpPermissionDelta\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.containerregistry.v1.IpPermissionActionB\x04\xe8\xc7\x31\x01\x12L\n\rip_permission\x18\x02 \x01(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermissionB\x04\xe8\xc7\x31\x01*O\n\x12IpPermissionAction\x12$\n IP_PERMISSION_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_IPPERMISSIONACTION = _descriptor.EnumDescriptor(
  name='IpPermissionAction',
  full_name='yandex.cloud.containerregistry.v1.IpPermissionAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IP_PERMISSION_ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=455,
  serialized_end=534,
)
_sym_db.RegisterEnumDescriptor(_IPPERMISSIONACTION)

IpPermissionAction = enum_type_wrapper.EnumTypeWrapper(_IPPERMISSIONACTION)
IP_PERMISSION_ACTION_UNSPECIFIED = 0
ADD = 1
REMOVE = 2


_IPPERMISSION_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='yandex.cloud.containerregistry.v1.IpPermission.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUSH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=224,
  serialized_end=276,
)
_sym_db.RegisterEnumDescriptor(_IPPERMISSION_ACTION)


_IPPERMISSION = _descriptor.Descriptor(
  name='IpPermission',
  full_name='yandex.cloud.containerregistry.v1.IpPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.containerregistry.v1.IpPermission.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='yandex.cloud.containerregistry.v1.IpPermission.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IPPERMISSION_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=276,
)


_IPPERMISSIONDELTA = _descriptor.Descriptor(
  name='IpPermissionDelta',
  full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_permission', full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta.ip_permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=453,
)

_IPPERMISSION.fields_by_name['action'].enum_type = _IPPERMISSION_ACTION
_IPPERMISSION_ACTION.containing_type = _IPPERMISSION
_IPPERMISSIONDELTA.fields_by_name['action'].enum_type = _IPPERMISSIONACTION
_IPPERMISSIONDELTA.fields_by_name['ip_permission'].message_type = _IPPERMISSION
DESCRIPTOR.message_types_by_name['IpPermission'] = _IPPERMISSION
DESCRIPTOR.message_types_by_name['IpPermissionDelta'] = _IPPERMISSIONDELTA
DESCRIPTOR.enum_types_by_name['IpPermissionAction'] = _IPPERMISSIONACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IpPermission = _reflection.GeneratedProtocolMessageType('IpPermission', (_message.Message,), {
  'DESCRIPTOR' : _IPPERMISSION,
  '__module__' : 'yandex.cloud.containerregistry.v1.ip_permission_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.IpPermission)
  })
_sym_db.RegisterMessage(IpPermission)

IpPermissionDelta = _reflection.GeneratedProtocolMessageType('IpPermissionDelta', (_message.Message,), {
  'DESCRIPTOR' : _IPPERMISSIONDELTA,
  '__module__' : 'yandex.cloud.containerregistry.v1.ip_permission_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.IpPermissionDelta)
  })
_sym_db.RegisterMessage(IpPermissionDelta)


DESCRIPTOR._options = None
_IPPERMISSIONDELTA.fields_by_name['action']._options = None
_IPPERMISSIONDELTA.fields_by_name['ip_permission']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/node_group_service.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/k8s/v1/node_group_service.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a$yandex/cloud/k8s/v1/node_group.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"2\n\x13GetNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x15ListNodeGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"f\n\x16ListNodeGroupsResponse\x12\x33\n\x0bnode_groups\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.NodeGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x19ListNodeGroupNodesRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x1aListNodeGroupNodesResponse\x12(\n\x05nodes\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.k8s.v1.Node\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x16\x44\x65leteNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\xa0\x08\n\x16UpdateNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x38\n\rnode_template\x18\x08 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplate\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicy\x12I\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\x0f \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x37\n\x07version\x18\n \x01(\x0b\x32&.yandex.cloud.k8s.v1.UpdateVersionSpec\x12K\n\x12maintenance_policy\x18\x0b \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\x0c \x03(\tBO\x8a\xc8\x31\x05<=253\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x12/\n\x0bnode_taints\x18\r \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0e \x03(\x0b\x32;.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x17UpdateNodeGroupMetadata\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xd0\x07\n\x16\x43reateNodeGroupRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12>\n\rnode_template\x18\x05 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplateB\x04\xe8\xc7\x31\x01\x12<\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicyB\x04\xe8\xc7\x31\x01\x12I\n\x11\x61llocation_policy\x18\x07 \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\r \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x0f\n\x07version\x18\x08 \x01(\t\x12K\n\x12maintenance_policy\x18\t \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\n \x03(\tBO\x8a\xc8\x31\x05<=253\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x12/\n\x0bnode_taints\x18\x0b \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0c \x03(\x0b\x32;.yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x17\x43reateNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"5\n\x1c\x41utoUpgradeNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\x97\x01\n\x1eListNodeGroupOperationsRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListNodeGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc1\t\n\x10NodeGroupService\x12\x8a\x01\n\x03Get\x12(.yandex.cloud.k8s.v1.GetNodeGroupRequest\x1a\x1e.yandex.cloud.k8s.v1.NodeGroup\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}\x12\x8a\x01\n\x04List\x12*.yandex.cloud.k8s.v1.ListNodeGroupsRequest\x1a+.yandex.cloud.k8s.v1.ListNodeGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-kubernetes/v1/nodeGroups\x12\xae\x01\n\x06\x43reate\x12+.yandex.cloud.k8s.v1.CreateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02&\"!/managed-kubernetes/v1/nodeGroups:\x01*\xb2\xd2*$\n\x17\x43reateNodeGroupMetadata\x12\tNodeGroup\x12\xbe\x01\n\x06Update\x12+.yandex.cloud.k8s.v1.UpdateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"d\x82\xd3\xe4\x93\x02\x36\x32\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}:\x01*\xb2\xd2*$\n\x17UpdateNodeGroupMetadata\x12\tNodeGroup\x12\xc7\x01\n\x06\x44\x65lete\x12+.yandex.cloud.k8s.v1.DeleteNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x33*1/managed-kubernetes/v1/nodeGroups/{node_group_id}\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x12\xc1\x01\n\x0eListOperations\x12\x33.yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest\x1a\x34.yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse\"D\x82\xd3\xe4\x93\x02>\x12</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations\x12\x92\x01\n\tListNodes\x12..yandex.cloud.k8s.v1.ListNodeGroupNodesRequest\x1a/.yandex.cloud.k8s.v1.ListNodeGroupNodesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-kubernetes/v1/nodesBV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETNODEGROUPREQUEST = _descriptor.Descriptor(
  name='GetNodeGroupRequest',
  full_name='yandex.cloud.k8s.v1.GetNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.GetNodeGroupRequest.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=393,
)


_LISTNODEGROUPSREQUEST = _descriptor.Descriptor(
  name='ListNodeGroupsRequest',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.k8s.v1.ListNodeGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.k8s.v1.ListNodeGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.k8s.v1.ListNodeGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=534,
)


_LISTNODEGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListNodeGroupsResponse',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_groups', full_name='yandex.cloud.k8s.v1.ListNodeGroupsResponse.node_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=638,
)


_LISTNODEGROUPNODESREQUEST = _descriptor.Descriptor(
  name='ListNodeGroupNodesRequest',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesRequest.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=758,
)


_LISTNODEGROUPNODESRESPONSE = _descriptor.Descriptor(
  name='ListNodeGroupNodesResponse',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesResponse.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupNodesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=855,
)


_DELETENODEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteNodeGroupRequest',
  full_name='yandex.cloud.k8s.v1.DeleteNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.DeleteNodeGroupRequest.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=910,
)


_DELETENODEGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteNodeGroupMetadata',
  full_name='yandex.cloud.k8s.v1.DeleteNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.DeleteNodeGroupMetadata.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=960,
)


_UPDATENODEGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=1968,
)

_UPDATENODEGROUPREQUEST_NODELABELSENTRY = _descriptor.Descriptor(
  name='NodeLabelsEntry',
  full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1970,
  serialized_end=2019,
)

_UPDATENODEGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateNodeGroupRequest',
  full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_template', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.node_template', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.scale_policy', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.allocation_policy', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.deploy_policy', index=8,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.version', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.maintenance_policy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_unsafe_sysctls', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.allowed_unsafe_sysctls', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=253\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_taints', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.node_taints', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_labels', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupRequest.node_labels', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATENODEGROUPREQUEST_LABELSENTRY, _UPDATENODEGROUPREQUEST_NODELABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=2019,
)


_UPDATENODEGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateNodeGroupMetadata',
  full_name='yandex.cloud.k8s.v1.UpdateNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.UpdateNodeGroupMetadata.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2075,
)


_CREATENODEGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=1968,
)

_CREATENODEGROUPREQUEST_NODELABELSENTRY = _descriptor.Descriptor(
  name='NodeLabelsEntry',
  full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1970,
  serialized_end=2019,
)

_CREATENODEGROUPREQUEST = _descriptor.Descriptor(
  name='CreateNodeGroupRequest',
  full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_template', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.node_template', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.scale_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.allocation_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.deploy_policy', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.version', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.maintenance_policy', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_unsafe_sysctls', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.allowed_unsafe_sysctls', index=10,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=253\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_taints', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.node_taints', index=11,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_labels', full_name='yandex.cloud.k8s.v1.CreateNodeGroupRequest.node_labels', index=12,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATENODEGROUPREQUEST_LABELSENTRY, _CREATENODEGROUPREQUEST_NODELABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=3054,
)


_CREATENODEGROUPMETADATA = _descriptor.Descriptor(
  name='CreateNodeGroupMetadata',
  full_name='yandex.cloud.k8s.v1.CreateNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.CreateNodeGroupMetadata.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3056,
  serialized_end=3104,
)


_AUTOUPGRADENODEGROUPMETADATA = _descriptor.Descriptor(
  name='AutoUpgradeNodeGroupMetadata',
  full_name='yandex.cloud.k8s.v1.AutoUpgradeNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.AutoUpgradeNodeGroupMetadata.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3106,
  serialized_end=3159,
)


_LISTNODEGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListNodeGroupOperationsRequest',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_group_id', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest.node_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3162,
  serialized_end=3313,
)


_LISTNODEGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListNodeGroupOperationsResponse',
  full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3315,
  serialized_end=3428,
)

_LISTNODEGROUPSRESPONSE.fields_by_name['node_groups'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUP
_LISTNODEGROUPNODESRESPONSE.fields_by_name['nodes'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._NODE
_UPDATENODEGROUPREQUEST_LABELSENTRY.containing_type = _UPDATENODEGROUPREQUEST
_UPDATENODEGROUPREQUEST_NODELABELSENTRY.containing_type = _UPDATENODEGROUPREQUEST
_UPDATENODEGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATENODEGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATENODEGROUPREQUEST_LABELSENTRY
_UPDATENODEGROUPREQUEST.fields_by_name['node_template'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._NODETEMPLATE
_UPDATENODEGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._SCALEPOLICY
_UPDATENODEGROUPREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUPALLOCATIONPOLICY
_UPDATENODEGROUPREQUEST.fields_by_name['deploy_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._DEPLOYPOLICY
_UPDATENODEGROUPREQUEST.fields_by_name['version'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2._UPDATEVERSIONSPEC
_UPDATENODEGROUPREQUEST.fields_by_name['maintenance_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUPMAINTENANCEPOLICY
_UPDATENODEGROUPREQUEST.fields_by_name['node_taints'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._TAINT
_UPDATENODEGROUPREQUEST.fields_by_name['node_labels'].message_type = _UPDATENODEGROUPREQUEST_NODELABELSENTRY
_CREATENODEGROUPREQUEST_LABELSENTRY.containing_type = _CREATENODEGROUPREQUEST
_CREATENODEGROUPREQUEST_NODELABELSENTRY.containing_type = _CREATENODEGROUPREQUEST
_CREATENODEGROUPREQUEST.fields_by_name['labels'].message_type = _CREATENODEGROUPREQUEST_LABELSENTRY
_CREATENODEGROUPREQUEST.fields_by_name['node_template'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._NODETEMPLATE
_CREATENODEGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._SCALEPOLICY
_CREATENODEGROUPREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUPALLOCATIONPOLICY
_CREATENODEGROUPREQUEST.fields_by_name['deploy_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._DEPLOYPOLICY
_CREATENODEGROUPREQUEST.fields_by_name['maintenance_policy'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUPMAINTENANCEPOLICY
_CREATENODEGROUPREQUEST.fields_by_name['node_taints'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._TAINT
_CREATENODEGROUPREQUEST.fields_by_name['node_labels'].message_type = _CREATENODEGROUPREQUEST_NODELABELSENTRY
_LISTNODEGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetNodeGroupRequest'] = _GETNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListNodeGroupsRequest'] = _LISTNODEGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListNodeGroupsResponse'] = _LISTNODEGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['ListNodeGroupNodesRequest'] = _LISTNODEGROUPNODESREQUEST
DESCRIPTOR.message_types_by_name['ListNodeGroupNodesResponse'] = _LISTNODEGROUPNODESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteNodeGroupRequest'] = _DELETENODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteNodeGroupMetadata'] = _DELETENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateNodeGroupRequest'] = _UPDATENODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateNodeGroupMetadata'] = _UPDATENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['CreateNodeGroupRequest'] = _CREATENODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateNodeGroupMetadata'] = _CREATENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['AutoUpgradeNodeGroupMetadata'] = _AUTOUPGRADENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListNodeGroupOperationsRequest'] = _LISTNODEGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListNodeGroupOperationsResponse'] = _LISTNODEGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNodeGroupRequest = _reflection.GeneratedProtocolMessageType('GetNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.GetNodeGroupRequest)
  })
_sym_db.RegisterMessage(GetNodeGroupRequest)

ListNodeGroupsRequest = _reflection.GeneratedProtocolMessageType('ListNodeGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPSREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupsRequest)
  })
_sym_db.RegisterMessage(ListNodeGroupsRequest)

ListNodeGroupsResponse = _reflection.GeneratedProtocolMessageType('ListNodeGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupsResponse)
  })
_sym_db.RegisterMessage(ListNodeGroupsResponse)

ListNodeGroupNodesRequest = _reflection.GeneratedProtocolMessageType('ListNodeGroupNodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPNODESREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupNodesRequest)
  })
_sym_db.RegisterMessage(ListNodeGroupNodesRequest)

ListNodeGroupNodesResponse = _reflection.GeneratedProtocolMessageType('ListNodeGroupNodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPNODESRESPONSE,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupNodesResponse)
  })
_sym_db.RegisterMessage(ListNodeGroupNodesResponse)

DeleteNodeGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DeleteNodeGroupRequest)
  })
_sym_db.RegisterMessage(DeleteNodeGroupRequest)

DeleteNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DeleteNodeGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteNodeGroupMetadata)

UpdateNodeGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateNodeGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATENODEGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntry)
    })
  ,

  'NodeLabelsEntry' : _reflection.GeneratedProtocolMessageType('NodeLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATENODEGROUPREQUEST_NODELABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATENODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.UpdateNodeGroupRequest)
  })
_sym_db.RegisterMessage(UpdateNodeGroupRequest)
_sym_db.RegisterMessage(UpdateNodeGroupRequest.LabelsEntry)
_sym_db.RegisterMessage(UpdateNodeGroupRequest.NodeLabelsEntry)

UpdateNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.UpdateNodeGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateNodeGroupMetadata)

CreateNodeGroupRequest = _reflection.GeneratedProtocolMessageType('CreateNodeGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATENODEGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntry)
    })
  ,

  'NodeLabelsEntry' : _reflection.GeneratedProtocolMessageType('NodeLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATENODEGROUPREQUEST_NODELABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATENODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.CreateNodeGroupRequest)
  })
_sym_db.RegisterMessage(CreateNodeGroupRequest)
_sym_db.RegisterMessage(CreateNodeGroupRequest.LabelsEntry)
_sym_db.RegisterMessage(CreateNodeGroupRequest.NodeLabelsEntry)

CreateNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.CreateNodeGroupMetadata)
  })
_sym_db.RegisterMessage(CreateNodeGroupMetadata)

AutoUpgradeNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('AutoUpgradeNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _AUTOUPGRADENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.AutoUpgradeNodeGroupMetadata)
  })
_sym_db.RegisterMessage(AutoUpgradeNodeGroupMetadata)

ListNodeGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListNodeGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListNodeGroupOperationsRequest)

ListNodeGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListNodeGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListNodeGroupOperationsResponse)


DESCRIPTOR._options = None
_GETNODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
_LISTNODEGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTNODEGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTNODEGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTNODEGROUPSREQUEST.fields_by_name['filter']._options = None
_LISTNODEGROUPNODESREQUEST.fields_by_name['node_group_id']._options = None
_LISTNODEGROUPNODESREQUEST.fields_by_name['page_size']._options = None
_LISTNODEGROUPNODESREQUEST.fields_by_name['page_token']._options = None
_DELETENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
_UPDATENODEGROUPREQUEST_LABELSENTRY._options = None
_UPDATENODEGROUPREQUEST_NODELABELSENTRY._options = None
_UPDATENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
_UPDATENODEGROUPREQUEST.fields_by_name['name']._options = None
_UPDATENODEGROUPREQUEST.fields_by_name['description']._options = None
_UPDATENODEGROUPREQUEST.fields_by_name['labels']._options = None
_UPDATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
_UPDATENODEGROUPMETADATA.fields_by_name['node_group_id']._options = None
_CREATENODEGROUPREQUEST_LABELSENTRY._options = None
_CREATENODEGROUPREQUEST_NODELABELSENTRY._options = None
_CREATENODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['name']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['description']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['labels']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['node_template']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['scale_policy']._options = None
_CREATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
_LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['node_group_id']._options = None
_LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['filter']._options = None

_NODEGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='NodeGroupService',
  full_name='yandex.cloud.k8s.v1.NodeGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3431,
  serialized_end=4648,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2._NODEGROUP,
    serialized_options=b'\202\323\344\223\0023\0221/managed-kubernetes/v1/nodeGroups/{node_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTNODEGROUPSREQUEST,
    output_type=_LISTNODEGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/managed-kubernetes/v1/nodeGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATENODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&\"!/managed-kubernetes/v1/nodeGroups:\001*\262\322*$\n\027CreateNodeGroupMetadata\022\tNodeGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATENODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002621/managed-kubernetes/v1/nodeGroups/{node_group_id}:\001*\262\322*$\n\027UpdateNodeGroupMetadata\022\tNodeGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETENODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023*1/managed-kubernetes/v1/nodeGroups/{node_group_id}\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTNODEGROUPOPERATIONSREQUEST,
    output_type=_LISTNODEGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNodes',
    full_name='yandex.cloud.k8s.v1.NodeGroupService.ListNodes',
    index=6,
    containing_service=None,
    input_type=_LISTNODEGROUPNODESREQUEST,
    output_type=_LISTNODEGROUPNODESRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/managed-kubernetes/v1/nodes',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODEGROUPSERVICE)

DESCRIPTOR.services_by_name['NodeGroupService'] = _NODEGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/storage_type_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ydb.v1 import storage_type_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ydb/v1/storage_type_service.proto',
  package='yandex.cloud.ydb.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/ydb/v1/storage_type_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/ydb/v1/storage_type.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetStorageTypeRequest\x12\x1d\n\x0fstorage_type_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17ListStorageTypesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x18ListStorageTypesResponse\x12\x37\n\rstorage_types\x18\x01 \x03(\x0b\x32 .yandex.cloud.ydb.v1.StorageType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9e\x02\n\x12StorageTypeService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.ydb.v1.GetStorageTypeRequest\x1a .yandex.cloud.ydb.v1.StorageType\".\x82\xd3\xe4\x93\x02(\x12&/ydb/v1/storageTypes/{storage_type_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.ydb.v1.ListStorageTypesRequest\x1a-.yandex.cloud.ydb.v1.ListStorageTypesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/ydb/v1/storageTypesBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSTORAGETYPEREQUEST = _descriptor.Descriptor(
  name='GetStorageTypeRequest',
  full_name='yandex.cloud.ydb.v1.GetStorageTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_type_id', full_name='yandex.cloud.ydb.v1.GetStorageTypeRequest.storage_type_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=226,
)


_LISTSTORAGETYPESREQUEST = _descriptor.Descriptor(
  name='ListStorageTypesRequest',
  full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=315,
)


_LISTSTORAGETYPESRESPONSE = _descriptor.Descriptor(
  name='ListStorageTypesResponse',
  full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_types', full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse.storage_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=425,
)

_LISTSTORAGETYPESRESPONSE.fields_by_name['storage_types'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2._STORAGETYPE
DESCRIPTOR.message_types_by_name['GetStorageTypeRequest'] = _GETSTORAGETYPEREQUEST
DESCRIPTOR.message_types_by_name['ListStorageTypesRequest'] = _LISTSTORAGETYPESREQUEST
DESCRIPTOR.message_types_by_name['ListStorageTypesResponse'] = _LISTSTORAGETYPESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStorageTypeRequest = _reflection.GeneratedProtocolMessageType('GetStorageTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGETYPEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.GetStorageTypeRequest)
  })
_sym_db.RegisterMessage(GetStorageTypeRequest)

ListStorageTypesRequest = _reflection.GeneratedProtocolMessageType('ListStorageTypesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGETYPESREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListStorageTypesRequest)
  })
_sym_db.RegisterMessage(ListStorageTypesRequest)

ListStorageTypesResponse = _reflection.GeneratedProtocolMessageType('ListStorageTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGETYPESRESPONSE,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListStorageTypesResponse)
  })
_sym_db.RegisterMessage(ListStorageTypesResponse)


DESCRIPTOR._options = None
_GETSTORAGETYPEREQUEST.fields_by_name['storage_type_id']._options = None
_LISTSTORAGETYPESREQUEST.fields_by_name['page_size']._options = None
_LISTSTORAGETYPESREQUEST.fields_by_name['page_token']._options = None

_STORAGETYPESERVICE = _descriptor.ServiceDescriptor(
  name='StorageTypeService',
  full_name='yandex.cloud.ydb.v1.StorageTypeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=428,
  serialized_end=714,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.ydb.v1.StorageTypeService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSTORAGETYPEREQUEST,
    output_type=yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2._STORAGETYPE,
    serialized_options=b'\202\323\344\223\002(\022&/ydb/v1/storageTypes/{storage_type_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.ydb.v1.StorageTypeService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSTORAGETYPESREQUEST,
    output_type=_LISTSTORAGETYPESRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/ydb/v1/storageTypes',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORAGETYPESERVICE)

DESCRIPTOR.services_by_name['StorageTypeService'] = _STORAGETYPESERVICE

# @@protoc_insertion_point(module_scope)
